@@ -1,21 +1,28 @@
 <?php
 /**
- * $Horde: horde/lib/Secret.php,v 1.12.2.4 2002/04/05 01:24:23 jon Exp $
- *
  * The Secret:: class provides an API for encrypting and decrypting
  * small pieces of data with the use of a shared key.
  *
- * The Secret:: functions use the PEAR Crypt/HCEMD5 module.
+ * The Secret:: functions use the Horde Crypt:: class if mcrypt is not
+ * available.
+ *
+ * $Horde: horde/lib/Secret.php,v 1.12.2.11 2003/01/09 13:00:52 jan Exp $
+ *
+ * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.12.2.4 $
+ * @version $Revision: 1.12.2.11 $
  * @since   Horde 1.3
- * @package horde
+ * @package horde.crypto
  */
 class Secret {
 
     /**
      * Take a small piece of data and encrypt it with a key.
+     *
      * @access public
      *
      * @param string $key      The key to use for encryption.
@@ -25,27 +32,34 @@ class Secret {
      */
     function write($key, $message)
     {
-        if (function_exists('mcrypt_is_broken')) {
-            Secret::srand();
+        if (extension_loaded('mcrypt')) {
+            Secret::_srand();
             $td = @mcrypt_module_open(MCRYPT_GOST, '', MCRYPT_MODE_ECB, '');
             if ($td) {
                 $iv = mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
                 @mcrypt_generic_init($td, $key, $iv);
                 $encrypted_data = mcrypt_generic($td, $message);
-                mcrypt_generic_end($td);
+                if (function_exists('mcrypt_generic_deinit')) {
+                    mcrypt_generic_deinit($td);
+                } else {
+                    mcrypt_generic_end($td);
+                }
 
                 return $encrypted_data;
             }
         }
 
-        include_once 'Crypt/HCEMD5.php';
+        require_once HORDE_BASE . '/lib/Cipher.php';
+        $cipher = &Horde_Cipher::factory('blowfish');
+        $cipher->setBlockMode("OFB64");
+        $cipher->setKey($key);
 
-        $hcemd5 = new Crypt_HCEMD5($key);
-        return $hcemd5->encodeMimeSelfRand($message);
+        return $cipher->encrypt($message);
     }
 
     /**
      * Decrypt a message encrypted with Secret::write().
+     *
      * @access public
      *
      * @param string $key      The key to use for decryption.
@@ -55,23 +69,29 @@ class Secret {
      */
     function read($key, $ciphertext)
     {
-        if (function_exists('mcrypt_is_broken')) {
-            Secret::srand();
+        if (extension_loaded('mcrypt')) {
+            Secret::_srand();
             $td = @mcrypt_module_open(MCRYPT_GOST, '', MCRYPT_MODE_ECB, '');
             if ($td) {
                 $iv = mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
                 @mcrypt_generic_init($td, $key, $iv);
                 $decrypted_data = mdecrypt_generic($td, $ciphertext);
-                mcrypt_generic_end($td);
+                if (function_exists('mcrypt_generic_deinit')) {
+                    mcrypt_generic_deinit($td);
+                } else {
+                    mcrypt_generic_end($td);
+                }
 
                 return $decrypted_data;
             }
         }
 
-        include_once 'Crypt/HCEMD5.php';
+        require_once HORDE_BASE . '/lib/Cipher.php';
+        $cipher = &Horde_Cipher::factory('blowfish');
+        $cipher->setBlockMode("OFB64");
+        $cipher->setKey($key);
 
-        $hcemd5 = new Crypt_HCEMD5($key);
-        return $hcemd5->decodeMimeSelfRand($ciphertext);
+        return $cipher->decrypt($ciphertext);
     }
 
     /**
@@ -80,22 +100,27 @@ class Secret {
      * enabled, or munging some known values if they don't.
      *
      * @access public
-     * @param optional string $keyname  The name of the key to set. Defaults to 'generic'.
-     * @return string The secret key that has been generated.
+     *
+     * @param optional string $keyname  The name of the key to set.
+     *
+     * @return string  The secret key that has been generated.
      */
     function setKey($keyname = 'generic')
     {
-        if (isset($GLOBALS['HTTP_COOKIE_VARS']) && isset($GLOBALS['HTTP_COOKIE_VARS'][session_name()])) {
-            if (isset($GLOBALS['HTTP_COOKIE_VARS'][$keyname . '_key'])) {
-                $key = $GLOBALS['HTTP_COOKIE_VARS'][$keyname . '_key'];
+        global $registry, $conf;
+
+        if (isset($_COOKIE) &&
+            array_key_exists($conf['session_name'], $_COOKIE)) {
+            if (array_key_exists($keyname . '_key', $_COOKIE)) {
+                $key = $_COOKIE[$keyname . '_key'];
             } else {
-                Secret::srand();
+                Secret::_srand();
                 $key = md5(uniqid(mt_rand()));
-                $GLOBALS['HTTP_COOKIE_VARS'][$keyname . '_key'] = $key;
-                setcookie($keyname . '_key', $key, null, $GLOBALS['registry']->getParam('cookie_path'), $GLOBALS['registry']->getParam('cookie_domain'));
+                $_COOKIE[$keyname . '_key'] = $key;
+                setcookie($keyname . '_key', $key, null, $registry->getParam('cookie_path'), $registry->getParam('cookie_domain'));
             }
         } else {
-            $key = md5(session_id() . $GLOBALS['registry']->getParam('server_name'));
+            $key = md5(session_id() . $registry->getParam('server_name'));
         }
 
         return $key;
@@ -107,23 +132,38 @@ class Secret {
      * base value.
      *
      * @access public
-     * @param optional string $keyname  The name of the key to get. Defaults to 'generic'.
-     * @return string The secret key.
+     *
+     * @param optional string $keyname  The name of the key to get.
+     *
+     * @return string  The secret key.
      */
     function getKey($keyname = 'generic')
     {
-        if (isset($GLOBALS['HTTP_COOKIE_VARS'][$keyname . '_key'])) {
-            return $GLOBALS['HTTP_COOKIE_VARS'][$keyname . '_key'];
-        } else {
-            return md5(session_id() . $GLOBALS['registry']->getParam('server_name'));
+        global $registry;
+        static $keycache;
+
+        if (is_null($keycache)) {
+            $keycache = array();
         }
+
+        if (!array_key_exists($keyname, $keycache)) {
+            if (array_key_exists($keyname . '_key', $_COOKIE)) {
+                $keycache[$keyname] = $_COOKIE[$keyname . '_key'];
+            } else {
+                global $conf;
+                $keycache[$keyname] = md5(session_id() . $registry->getParam('server_name'));
+            }
+        }
+
+        return $keycache[$keyname];
     }
 
     /**
      * Ensure that the random number generator is initialized only once.
+     *
      * @access private
      */
-    function srand()
+    function _srand()
     {
         static $initialized;
 
@@ -134,4 +174,3 @@ class Secret {
     }
 
 }
-?>
