@@ -1,9 +1,9 @@
 <?php
 /*
- * $Horde: horde/login.php,v 2.55.2.13 2002/06/08 04:15:55 chuck Exp $
+ * $Horde: horde/login.php,v 2.55.2.18 2003/01/03 12:57:44 jan Exp $
  *
- * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2002 Jon Parise <jon@horde.org>
+ * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2003 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -19,7 +19,7 @@ if (Horde::getFormData('reason') == 'logout') {
         exit;
     } else {
         $entry = sprintf('User %s [%s] logged out of Horde',
-                         Auth::getAuth(), $HTTP_SERVER_VARS['REMOTE_ADDR']);
+                         Auth::getAuth(), $_SERVER['REMOTE_ADDR']);
         Horde::logMessage($entry, __FILE__, __LINE__, LOG_NOTICE);
         Auth::clearAuth();
         session_destroy();
@@ -27,17 +27,17 @@ if (Horde::getFormData('reason') == 'logout') {
     }
 }
 
-if (isset($HTTP_POST_VARS['horde_user']) &&
-    isset($HTTP_POST_VARS['horde_pass'])) {
+if (isset($_POST['horde_user']) &&
+    isset($_POST['horde_pass'])) {
     $auth = &Auth::singleton($conf['auth']['driver'], $conf['auth']['params']);
     if ($auth->authenticate(Horde::getFormData('horde_user'),
                             array('password' => Horde::getFormData('horde_pass')))) {
         $entry = sprintf('Login success for %s [%s] to Horde',
-                         Auth::getAuth(), $HTTP_SERVER_VARS['REMOTE_ADDR']);
+                         Auth::getAuth(), $_SERVER['REMOTE_ADDR']);
         $level = LOG_INFO;
     } else {
         $entry = sprintf('FAILED LOGIN for %s [%s] to Horde',
-                         Horde::getFormData('horde_user'), $HTTP_SERVER_VARS['REMOTE_ADDR']);
+                         Horde::getFormData('horde_user'), $_SERVER['REMOTE_ADDR']);
         $level = LOG_ERR;
     }
     Horde::logMessage($entry, __FILE__, __LINE__, $level);
@@ -68,11 +68,17 @@ if (Auth::getAuth()) {
         $refresh_url = Horde::applicationUrl('login.php');
     }
     include_once HORDE_BASE . '/lib/Menu.php';
-    $fullname = Auth::getAuth();
+    include_once HORDE_BASE . '/lib/Identity.php';
+    $identity = new Identity();
+    $fullname = $identity->getValue('fullname');
+    if (empty($fullname)) {
+        $fullname = Auth::getAuth();
+    }
     $template = 'user.inc';
     $columns = array();
-    foreach ($registry->applications as $app => $info) {
-        if (isset($registry->services[$app]['horde']['summary']) && $registry->getParam('show', $app)) {
+    $pref_num_columns = $prefs->getValue('summary_columns');
+    foreach ($registry->listApps() as $app) {
+        if (isset($registry->services[$app]['horde']['summary'])) {
             $summary = $registry->callByPackage($app, 'horde/summary');
             if (!PEAR::isError($summary)) {
                 $columns[] = $summary;
@@ -80,7 +86,7 @@ if (Auth::getAuth()) {
         }
     }
     if (count($columns) > 0) {
-        $width = round(100 / count($columns));
+        $width = round(100 / $pref_num_columns);
     }
 } elseif ($registry->hasMethod('auth/login')) {
     $url = Horde::getFormData('url', Horde::selfURL());
